@@ -68,6 +68,7 @@ PajeContainer::~PajeContainer ()
 
 void PajeContainer::init (std::string alias, PajeContainer *parent)
 {
+  dumped = false;
   _alias = alias;
   _destroyed = false;
   if (parent){
@@ -148,6 +149,13 @@ bool PajeContainer::keepSimulating (void)
   return true;
 }
 
+std::string PajeContainer::descriptionHeader (void) const
+{
+  std::stringstream description;
+  description << "Container, Parent, Type, Start, End, Duration, Name";
+  return description.str();
+}
+
 std::string PajeContainer::description (void) const
 {
   std::stringstream description;
@@ -172,6 +180,12 @@ bool PajeContainer::isContainer (void) const
   return true;
 }
 
+bool PajeContainer::isComplete (void) const
+{
+  return (PajeNamedEntity::isComplete() &&
+	  _destroyed == true);
+}
+
 const std::string &PajeContainer::identifier ()
 {
   return _alias.empty() ? name() : _alias;
@@ -239,7 +253,7 @@ void PajeContainer::demuxer (PajeEvent *event)
       throw PajeSimulationException ("Asked to simulate something I don't know how to simulate");
     }
   }else{
-    throw PajeSimulationException ("Unknow event id.");
+    throw PajeSimulationException ("Unknown event id.");
   }
 
   //update container endtime
@@ -291,6 +305,7 @@ void PajeContainer::pajePushState (PajeEvent *event)
     if (!stack->empty()){
       PajeUserState *top_of_stack = stack->back();
       top_of_stack->setEndTime (time);
+      top_of_stack->addPajeTraceEvent (traceEvent);
     }
   }
 
@@ -323,6 +338,7 @@ void PajeContainer::pajePopState (PajeEvent *event)
   //update the top of the stack, set its endTime
   PajeUserState *last_stacked = stack->back();
   last_stacked->setEndTime (time);
+  last_stacked->addPajeTraceEvent (traceEvent);
 
   //pop the stack
   stack->pop_back();
@@ -819,3 +835,62 @@ void PajeContainer::destroy (double time)
   //recursive destroy because parent container is being destroyed
   recursiveDestroy(time);
 }
+
+
+void PajeContainer::recursiveClearCompleteEntities (std::ostream& output, bool deleteCompleteContainer)
+{
+  //clear local complete entities
+  for (auto const &childEntity : entities){
+    std::vector<PajeEntity*> children = (childEntity.second);
+    std::vector<PajeEntity*>::iterator it = children.begin();
+    while (it != children.end()){
+      PajeEntity *child = *it;
+      if (child->isComplete()){
+	child->dump(output);
+	it = children.erase(it);
+	delete child;
+      }else{
+	break;
+      }
+    }
+    entities[childEntity.first] = children;
+  }
+
+  //recurse in children
+  for(auto const &child : children) {
+    PajeContainer *child_container = (child.second);
+    child_container->recursiveClearCompleteEntities(output, deleteCompleteContainer);
+  }
+
+  //dump complete sub-containers
+  std::map<std::string,PajeContainer*>::iterator it = children.begin();
+  while (it != children.end()){
+    PajeContainer *subcontainer = (*it).second;
+    if (subcontainer->isComplete()){
+      subcontainer->dump(output);
+    }
+    it++;
+  }
+
+  //delete complete sub-containers
+  if (deleteCompleteContainer){
+    std::map<std::string,PajeContainer*>::iterator it = children.begin();
+    while (it != children.end()){
+      PajeContainer *subcontainer = (*it).second;
+      if (subcontainer->isComplete()){
+	it = children.erase(it);
+	delete subcontainer;
+      }else{
+	it++;
+      }
+    }
+  }
+}
+
+void PajeContainer::dump (std::ostream& output)
+{
+  if (!dumped){
+    PajeEntity::dump(output);
+    dumped = true;
+  }
+}
