@@ -18,6 +18,7 @@
 #include "omp.h"
 #endif
 #include "PajeUnity.h"
+#include "PajeException.h"
 #include <argp.h>
 #include "libpaje_config.h"
 
@@ -237,11 +238,11 @@ main(int argc, char **argv)
   arguments.start1 = arguments.end1 = arguments.stopat1 = -1;
   arguments.start2 = arguments.end2 = arguments.stopat2 = -1;
   if (argp_parse (&argp, argc, argv, 0, 0, &arguments) == ARGP_KEY_ERROR){
-    fprintf(stderr, "%s, error during the parsing of parameters\n", argv[0]);
+    fprintf(stderr, "Error during the parsing of parameters\n");
     exit(2);
   }
-  PajeUnity *s1;
-  PajeUnity *s2;
+  PajeUnity *s1 = NULL;
+  PajeUnity *s2 = NULL;
 #if defined(OPENMP)
 #pragma omp parallel sections num_threads(2)
 #endif
@@ -250,17 +251,29 @@ main(int argc, char **argv)
 #pragma omp section
 #endif
     {
-      s1 = new PajeUnity(arguments.flex, !arguments.noStrict,
-          std::string(arguments.input[0]), arguments.stopat1,
-			 arguments.ignoreIncompleteLinks, 0, false, false, false, false, false);
+      try {
+	s1 = new PajeUnity(arguments.flex, !arguments.noStrict,
+			   std::string(arguments.input[0]), arguments.stopat1,
+			   arguments.ignoreIncompleteLinks, 0, false, false, false, false, false);
+      }catch (PajeException &e){
+	e.report();
+	fprintf(stderr, "Error during the parsing of the input file\n");
+	return 1;
+      }
     }
 #if defined(OPENMP)
 #pragma omp section
 #endif
     {
-      s2 = new PajeUnity(arguments.flex, !arguments.noStrict,
-          std::string(arguments.input[1]), arguments.stopat2,
-			 arguments.ignoreIncompleteLinks, 0, false, false, false, false, false);
+      try {
+	s2 = new PajeUnity(arguments.flex, !arguments.noStrict,
+			   std::string(arguments.input[1]), arguments.stopat2,
+			   arguments.ignoreIncompleteLinks, 0, false, false, false, false, false);
+      }catch (PajeException &e){
+	e.report();
+	fprintf(stderr, "%s, error during the parsing of the input file %s\n", argv[0], arguments.input[1]);
+	return 1;
+      }
     }
   }
 
